@@ -22,11 +22,11 @@ class CaseInsensitiveEnum(Enum):
     @classmethod
     def _missing_(cls, value):
         if value is None:
-            return super()._missing_(cls, value)
+            return super()._missing_(value)
         for member in cls:
             if member.name.upper() == value.upper():
                 return member
-        super()._missing_(cls, value)
+        super()._missing_(value)
 
 IS_PRODUCTION = None
 def is_production():
